% This code is currently written to symbolically create the matrices
% derived using Galerkin's method on the MWR function for a 2-d square
% element heat transfer problem.  The boundaries are currently set with
% convection and one of the edges has dramatically larger convection due to
% the chill plate.
function [C,Ktot,Rtot] = SymbolicEqns_LinearShape(dx,dy,h,Tamb,rho,cp)
% clc;close;clear;
% rho = 2250;
% cp = 980;
% h=[5 0 0 0];
% Tamb = [298 0 0 0];
% dx = .1; %m
% dy = .1; %m

xc = dx/2;
yc = dy/2;
y1 = 0;
x1 = 0;
y2 = dy;
x2 = dx;
% rho = 2200; %kg/m^3, average density of the lithium battery
% cp = 980; %J/(kg-K), average specific heat of the lithium battery

kx = 25; %W/(m-K), thermal conductivity of the Li-batt in the x-direction
ky = 25; %W/(m-K), thermal conductivity of the Li-batt in the y-direction
 
h1 = h(1); %W/(m^2-K), heat transfer coefficient at the bottom edge of the cell
h2 = h(2); %W/(m^2-K), heat transfer coefficient at the right edge of the cell
h3 = h(3); %W/(m^2-K), heat transfer coefficient at the top edge of the cell
h4 = h(4); %W/(m^2-K), heat transfer coefficient at the left edge of the cell

Te1 = Tamb(1);
Te2 = Tamb(2);
Te3 = Tamb(3);
Te4 = Tamb(4);
 
% Shape functions 
syms x y
psi = 2*(x-xc)/dx; eta = 2*(y-yc)/dy;
N1 = .25*(1-psi)*(1-eta);
N2 = .25*(1+psi)*(1-eta);
N3 = .25*(1+psi)*(1+eta);
N4 = .25*(1-psi)*(1+eta);

% derviatives of the shape functions to be used for temperature gradient
% interpolation
dN1_dx = diff(N1,x);dN2_dx = diff(N2,x);dN3_dx = diff(N3,x);dN4_dx = diff(N4,x);
dN1_dy = diff(N1,y);dN2_dy = diff(N2,y);dN3_dy = diff(N3,y);dN4_dy = diff(N4,y);

% Create matrices of the shape functions and the derivatives
N_row = [N1 N2 N3 N4];
N_mat = N_row'*N_row;

B_mat = [dN1_dx dN2_dx dN3_dx dN4_dx; dN1_dy dN2_dy dN3_dy dN4_dy];

BT_B = B_mat'*B_mat;

%% Perform integration in order to get element matrices C and K

% Get [C] matrix
C1 = int(N_mat,x,x1,x2);
C = rho*cp*int(C1,y,y1,y2);

% Get [Kcond] matrix
D = [kx 0;0 ky];
BT_Bcond = B_mat'*D*B_mat;

Kc = int(int(BT_Bcond,x,x1,x2),y,y1,y2);

% Get the [Kconv] matrices; there's one for each boundary (four for the square element)
Kh1 = h1*int(subs(N_mat,y,y1),x,x1,x2);
Kh2 = h2*int(subs(N_mat,x,x2),y,y1,y2);
Kh3 = h3*int(subs(N_mat,y,y2),x,x1,x2);
Kh4 = h4*int(subs(N_mat,x,x1),y,y1,y2);

Ktot = Kc + (Kh1 + Kh2 + Kh3 + Kh4);

%% Finally the right side vectors are to be derived

% Internal heat generation
Q = 0;
R_Q1 = int(N_row',x,x1,x2);
R_Q = int(R_Q1,y,y1,y2);
R_Q = Q*R_Q;

% Convective resistance term
R_h1 = h1*Te1*int(subs(N_row',y,y1),x,x1,x2);
R_h2 = h2*Te2*int(subs(N_row',x,x2),y,y1,y2);
R_h3 = h3*Te3*int(subs(N_row',y,y2),x,x1,x2);
R_h4 = h4*Te4*int(subs(N_row',x,x1),y,y1,y2);

Rtot = R_Q + (R_h1 + R_h2 + R_h3 + R_h4);



