% This code is currently written to symbolically create the matrices
% derived using Galerkin's method on the MWR function for a 2-d square
% element heat transfer problem.  The boundaries are currently set with
% convection and one of the edges has dramatically larger convection due to
% the chill plate.
function [C,Ktot,Rtot] = SymbolicEqns_QuadraticShape(dx,dy)
% clc;close;clear;
% 
% dx = .1; %m
% dy = .1; %m
xc = dx/2;
yc = dy/2;

x1 = -xc; y1 = -yc;
x2 = 0;   y2 = -yc;
x3 = xc;  y3 = -yc;
x4 = xc;  y4 = 0;
x5 = xc;  y5 = yc;
x6 = 0;   y6 = yc;
x7 = -xc; y7 = yc;
x8 = -xc; y8 = 0;

rho = 2200; %kg/m^3, average density of the lithium battery
cp = 980; %J/(kg-K), average specific heat of the lithium battery

kx = 25; %W/(m-K), thermal conductivity of the Li-batt in the x-direction
ky = 25; %W/(m-K), thermal conductivity of the Li-batt in the y-direction
 
h1 = 5; %W/(m^2-K), heat transfer coefficient at the bottom edge of the cell
h2 = 5; %W/(m^2-K), heat transfer coefficient at the right edge of the cell
h3 = 135; %W/(m^2-K), heat transfer coefficient at the top edge of the cell
h4 = 135; %W/(m^2-K), heat transfer coefficient at the left edge of the cell
h5 = 135; %W/(m^2-K), heat transfer coefficient at the bottom edge of the cell
h6 = 5; %W/(m^2-K), heat transfer coefficient at the right edge of the cell
h7 = 5; %W/(m^2-K), heat transfer coefficient at the top edge of the cell
h8 = 5; %W/(m^2-K), heat transfer coefficient at the left edge of the cell

Tamb = 273.1+25;
Tcool = 273.1+5;

Te1 = Tamb;
Te2 = Tamb;
Te3 = Tcool;
Te4 = Tcool;
Te5 = Tcool;
Te6 = Tamb;
Te7 = Tamb;
Te8 = Tamb; 

% Quadratic serendipity Shape functions 
syms x y 
psi = 2*(x-xc)/dx; eta = 2*(y-yc)/dy;
    %Corner nodes
N1 = .25*(1-psi)*(1-eta)*(-psi-eta-1);
N3 = .25*(1+psi)*(1-eta)*(psi-eta-1);
N5 = .25*(1+psi)*(1+eta)*(psi+eta-1);
N7 = .25*(1-psi)*(1+eta)*(-psi+eta-1);
    % Mid vert-nodes (psi = 0)
N2 = .5*(1-psi^2)*(1-eta);
N6 = .5*(1-psi^2)*(1+eta);
    % Mid horiz-nodes (eta = 0)
N4 = .5*(1+psi)*(1-eta^2);
N8 = .5*(1-psi)*(1-eta^2);

% derviatives of the shape functions to be used for temperature gradient
% interpolation
dN1_dx = diff(N1,x);dN2_dx = diff(N2,x);dN3_dx = diff(N3,x);dN4_dx = diff(N4,x); dN5_dx = diff(N5,x);dN6_dx = diff(N6,x);dN7_dx = diff(N7,x);dN8_dx = diff(N8,x);
dN1_dy = diff(N1,y);dN2_dy = diff(N2,y);dN3_dy = diff(N3,y);dN4_dy = diff(N4,y);dN5_dy = diff(N5,y);dN6_dy = diff(N6,y);dN7_dy = diff(N7,y);dN8_dy = diff(N8,y);

% Create matrices of the shape functions and the derivatives
N_row = [N1 N2 N3 N4 N5 N6 N7 N8];
N_mat = N_row'*N_row;

B_mat = [dN1_dx dN2_dx dN3_dx dN4_dx dN5_dx dN6_dx dN7_dx dN8_dx; dN1_dy dN2_dy dN3_dy dN4_dy dN5_dy dN6_dy dN7_dy dN8_dy];

%BT_B = B_mat'*B_mat;

%% Perform integration in order to get element matrices C and K

% Get [C] matrix
C1 = int(N_mat,x,x1,x3);
C = rho*cp*int(C1,y,y1,y7);

% Get [Kcond] matrix
D = [kx 0;0 ky];
BT_Bcond = B_mat'*D*B_mat;

Kc = int(int(BT_Bcond,x,x1,x2),y,y1,y2);

% Get the [Kconv] matrices; there's one for each boundary (four for the square element)
Kh1 = h1*int(subs(N_mat,y,y1),x,x1,x2);
Kh2 = h2*int(subs(N_mat,y,y2),x,x2,x3);
Kh3 = h3*int(subs(N_mat,x,x3),y,y3,y4);
Kh4 = h4*int(subs(N_mat,x,x4),y,y4,y5);
Kh5 = h5*int(subs(N_mat,y,y5),x,x6,x5);
Kh6 = h6*int(subs(N_mat,y,y6),x,x7,x6);
Kh7 = h7*int(subs(N_mat,x,x7),y,y8,y7);
Kh8 = h8*int(subs(N_mat,x,x8),y,y1,y8);

Ktot = Kc + (Kh1 + Kh2 + Kh3 + Kh4 + Kh5 + Kh6 + Kh7 + Kh8);

%% Finally the right side vectors are to be derived

% Internal heat generation
Q = 0;
R_Q1 = int(N_row',x,x1,x3);
R_Q = int(R_Q1,y,y1,y7);
R_Q = Q*R_Q;

% Convective resistance term
R_h1 = h1*Te1*int(subs(N_row',y,y1),x,x1,x2);
R_h2 = h2*Te2*int(subs(N_row',y,y2),x,x2,x3);
R_h3 = h3*Te3*int(subs(N_row',x,x3),y,y3,y4);
R_h4 = h4*Te4*int(subs(N_row',x,x4),y,y4,y5);
R_h5 = h5*Te5*int(subs(N_row',y,y5),x,x6,x5);
R_h6 = h6*Te6*int(subs(N_row',y,y6),x,x7,x6);
R_h7 = h7*Te7*int(subs(N_row',x,x7),y,y8,y7);
R_h8 = h8*Te8*int(subs(N_row',x,x8),y,y1,y8);

Rtot = R_Q + (R_h1 + R_h2 + R_h3 + R_h4 + R_h5 + R_h6 + R_h7 + R_h8);

